@@ -121,6 +121,7 @@ int read_ahead;
 int editable;
 int blend_msecs;
 int perfmon = 0;
+int interactive = 0;
 
 /* font handling */
 static char *fontname = NULL;
@@ -788,6 +789,12 @@ svga_show(struct flist *f, struct flist *prev,
         if (check_console_switch()) {
 	    continue;
 	}
+
+	if (!interactive) {
+	    sleep(timeout);
+	    return -1;
+	}
+
 	FD_ZERO(&set);
 	FD_SET(0, &set);
 	fdmax = 1;
@@ -1371,6 +1378,7 @@ int main(int argc, char *argv[])
     autodown    = GET_AUTO_DOWN();
     fitwidth    = GET_FIT_WIDTH();
     statusline  = GET_VERBOSE();
+    comments    = GET_COMMENTS();
     textreading = GET_TEXT_MODE();
     editable    = GET_EDIT();
     backup      = GET_BACKUP();
@@ -1383,6 +1391,7 @@ int main(int argc, char *argv[])
     h_steps     = GET_SCROLL();
     timeout     = GET_TIMEOUT();
     pcd_res     = GET_PCD_RES();
+    interactive = GET_INTERACTIVE();
 
     fontname    = cfg_get_str(O_FONT);
     filelist    = cfg_get_str(O_FILE_LIST);
